OC.L10N.register(
    "notes",
    {
    "Notes" : "Note",
    "New note" : "Notă nouă",
    "Delete note" : "Şterge nota",
    "_%n word_::_%n words_" : ["%n cuvânt","%n cuvinte","%n cuvinte"]
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
